@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 import os
 import logging
 import random
+from distutils.version import LooseVersion
 
 import django
 import django.conf
@@ -122,8 +123,5 @@ def configure(smtp_string, loglevel):
             "registration",
             "mini_buildd"))
 
-    try:
-        # django 1.7
+    if LooseVersion(django.get_version()) >= LooseVersion("1.7.0"):
         django.setup()
-    except:
-        pass
